[Zope3-checkins] CVS: Zope3/src/zope/schema - interfaces.py:1.37

Fred L. Drake, Jr. fred at zope.com
Tue Jan 6 10:44:52 EST 2004


Update of /cvs-repository/Zope3/src/zope/schema
In directory cvs.zope.org:/tmp/cvs-serv3261

Modified Files:
	interfaces.py 
Log Message:
fix typos


=== Zope3/src/zope/schema/interfaces.py 1.36 => 1.37 ===
--- Zope3/src/zope/schema/interfaces.py:1.36	Mon Jan  5 06:31:08 2004
+++ Zope3/src/zope/schema/interfaces.py	Tue Jan  6 10:44:51 2004
@@ -124,12 +124,12 @@
         )
 
     def constraint(value):
-        u"""Check a customized contraint on the value.
+        u"""Check a customized constraint on the value.
 
         You can implement this method with your Field to
         require a certain constraint.  This relaxes the need
         to inherit/subclass a Field you to add a simple contraint.
         Returns true if the given value is within the Field's contraint.
         """
 
     def validate(value):
@@ -260,14 +260,14 @@
     # XXX IEnumerated will be removed in the future.
     u"""Field containing a byte string (like the python str).
 
-    The value might be contrained to be with length limits.
+    The value might be constrained to be with length limits.
     """
 
 class IASCII(IMinMaxLen, IEnumerated, IIterable, IField):
     # XXX IEnumerated will be removed in the future.
     u"""Field containing a byte string (like the python str).
 
-    The value might be contrained to be with length limits.
+    The value might be constrained to be with length limits.
     """
 
 class IBytesLine(IBytes):
@@ -124,12 +124,12 @@
         You can implement this method with your Field to
         require a certain constraint.  This relaxes the need
-        to inherit/subclass a Field you to add a simple contraint.
-        Returns true if the given value is within the Field's contraint.
+        to inherit/subclass a Field you to add a simple constraint.
+        Returns true if the given value is within the Field's constraint.
         """
 




More information about the Zope3-Checkins mailing list